@@ -308,10 +308,11 @@ class OKULAR_EXPORT Generator : public QObject
         virtual void generateTextPage( Page * page );
 
         /**
-         * Returns the general information object of the document or 0 if
-         * no information are available.
+         * Returns the general information object of the document.
+         *
+         * Changed signature in okular version 0.21
          */
-        virtual const DocumentInfo * generateDocumentInfo();
+        virtual DocumentInfo generateDocumentInfo( const QSet<DocumentInfo::Key> &keys ) const;
 
         /**
          * Returns the 'table of content' object of the document or 0 if
@@ -537,15 +538,6 @@ class OKULAR_EXPORT Generator : public QObject
          */
         void requestFontData(const Okular::FontInfo &font, QByteArray *data);
 
-        /**
-        * Asks the generator to dynamically generate a SourceReference for a given
-        * page number and absolute X and Y position on this page.
-        *
-        * @attention Ownership of the returned SourceReference is transferred to the caller.
-        * @since 0.10 (KDE 4.4)
-        */
-        const SourceReference * dynamicSourceReference( int pageNr, double absX, double absY );
-        
         /**
          * Returns the last print error in case print() failed
          * @since 0.11 (KDE 4.5)
