@@ -26,7 +26,7 @@ class GSGenerator : public Okular::Generator, public Okular::ConfigInterface
         bool loadDocument( const QString & fileName, QVector< Okular::Page * > & pagesVector );
 
         // Document description and Table of contents
-        const Okular::DocumentInfo * generateDocumentInfo();
+        Okular::DocumentInfo generateDocumentInfo( const QSet<Okular::DocumentInfo::Key> &keys ) const;
         const Okular::DocumentSynopsis * generateDocumentSynopsis() { return 0L; }
         const Okular::DocumentFonts * generateDocumentFonts() { return 0L; }
 
@@ -59,7 +59,6 @@ class GSGenerator : public Okular::Generator, public Okular::ConfigInterface
 
         // backendish stuff
         SpectreDocument *m_internalDocument;
-        Okular::DocumentInfo *m_docInfo;
 
         Okular::PixmapRequest *m_request;
 
