@@ -67,8 +67,6 @@ public:
   bool isValid() const;
 
 public slots:
-  void slotQuit();
-  
   Q_SCRIPTABLE Q_NOREPLY void tryRaise();
   Q_SCRIPTABLE bool openDocument( const QString& url, const QString &serializedOptions = QString() );
   Q_SCRIPTABLE bool canOpenDocs( int numDocs, int desktop );
@@ -86,6 +84,13 @@ protected:
    * with @ref saveProperties
    */
   void readProperties(const KConfigGroup&);
+
+  /**
+   * Expose internal functions for session restore testing
+   */
+  void savePropertiesInternal(KConfig* config, int num) {KMainWindow::savePropertiesInternal(config,num);}
+  void readPropertiesInternal(KConfig* config, int num) {KMainWindow::readPropertiesInternal(config,num);}
+
   void readSettings();
   void writeSettings();
   void setFullScreen( bool );
@@ -117,10 +122,6 @@ private slots:
   void handleTabDrop( QDropEvent* event );
   void moveTabData( int from, int to );
 
-signals:
-  void restoreDocument(const KConfigGroup &group);
-  void saveDocumentRestoreInfo(KConfigGroup &group);
-
 private:
   void setupAccel();
   void setupActions();
